You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@continuum.apache.org by oc...@apache.org on 2010/05/06 11:23:34 UTC

svn commit: r941625 [18/24] - in /continuum/branches/continuum-flat-multi-module: ./ continuum-api/ continuum-api/src/main/java/org/apache/continuum/builder/distributed/ continuum-api/src/main/java/org/apache/continuum/builder/distributed/manager/ cont...

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildDefinitionTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildDefinitionTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildDefinitionTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildDefinitionTest.java Thu May  6 09:23:13 2010
@@ -33,9 +33,9 @@ public class BuildDefinitionTest
     public void testDefaultGroupBuildDefinition()
         throws Exception
     {
-        String DEFAULT_PROJ_GRP_NAME = p.getProperty( "DEFAULT_PROJ_GRP_NAME" );
-        String DEFAULT_PROJ_GRP_ID = p.getProperty( "DEFAULT_PROJ_GRP_ID" );
-        String DEFAULT_PROJ_GRP_DESCRIPTION = p.getProperty( "DEFAULT_PROJ_GRP_DESCRIPTION" );
+        String DEFAULT_PROJ_GRP_NAME = getProperty( "DEFAULT_PROJ_GRP_NAME" );
+        String DEFAULT_PROJ_GRP_ID = getProperty( "DEFAULT_PROJ_GRP_ID" );
+        String DEFAULT_PROJ_GRP_DESCRIPTION = getProperty( "DEFAULT_PROJ_GRP_DESCRIPTION" );
 
         goToGroupBuildDefinitionPage( DEFAULT_PROJ_GRP_NAME, DEFAULT_PROJ_GRP_ID, DEFAULT_PROJ_GRP_DESCRIPTION );
         String tableElement = "ec_table";
@@ -70,9 +70,9 @@ public class BuildDefinitionTest
     public void testAddInvalidGroupBuildDefinition()
         throws Exception
     {
-        String TEST2_PROJ_GRP_NAME = p.getProperty( "TEST2_PROJ_GRP_NAME" );
-        String TEST2_PROJ_GRP_ID = p.getProperty( "TEST2_PROJ_GRP_ID" );
-        String TEST2_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
+        String TEST2_PROJ_GRP_NAME = getProperty( "TEST2_PROJ_GRP_NAME" );
+        String TEST2_PROJ_GRP_ID = getProperty( "TEST2_PROJ_GRP_ID" );
+        String TEST2_PROJ_GRP_DESCRIPTION = getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
         goToGroupBuildDefinitionPage( TEST2_PROJ_GRP_NAME, TEST2_PROJ_GRP_ID, TEST2_PROJ_GRP_DESCRIPTION );
         clickButtonWithValue( "Add" );
         setFieldValue( "buildFile", "" );
@@ -84,25 +84,25 @@ public class BuildDefinitionTest
     public void testBuildFromGroupBuildDefinition()
         throws Exception
     {
-        String TEST2_PROJ_GRP_NAME = p.getProperty( "TEST2_PROJ_GRP_NAME" );
-        String TEST2_PROJ_GRP_ID = p.getProperty( "TEST2_PROJ_GRP_ID" );
-        String TEST2_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
+        String TEST2_PROJ_GRP_NAME = getProperty( "TEST2_PROJ_GRP_NAME" );
+        String TEST2_PROJ_GRP_ID = getProperty( "TEST2_PROJ_GRP_ID" );
+        String TEST2_PROJ_GRP_DESCRIPTION = getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
         goToGroupBuildDefinitionPage( TEST2_PROJ_GRP_NAME, TEST2_PROJ_GRP_ID, TEST2_PROJ_GRP_DESCRIPTION );
         clickImgWithAlt( "Build" );
-        assertProjectGroupsSummaryPage();
+        assertProjectGroupSummaryPage( TEST2_PROJ_GRP_NAME, TEST2_PROJ_GRP_ID, TEST2_PROJ_GRP_DESCRIPTION );
     }
 
     @Test( dependsOnMethods = { "testAddProjectGroup2" } )
     public void testAddDefautltGroupBuildDefinition()
         throws Exception
     {
-        String TEST2_PROJ_GRP_NAME = p.getProperty( "TEST2_PROJ_GRP_NAME" );
-        String TEST2_PROJ_GRP_ID = p.getProperty( "TEST2_PROJ_GRP_ID" );
-        String TEST2_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
-        String BUILD_POM_NAME = p.getProperty( "BUILD_POM_NAME" );
-        String BUILD_GOALS = p.getProperty( "BUILD_GOALS" );
-        String BUILD_ARGUMENTS = p.getProperty( "BUILD_ARGUMENTS" );
-        String BUILD_DESCRIPTION = p.getProperty( "BUILD_DESCRIPTION" );
+        String TEST2_PROJ_GRP_NAME = getProperty( "TEST2_PROJ_GRP_NAME" );
+        String TEST2_PROJ_GRP_ID = getProperty( "TEST2_PROJ_GRP_ID" );
+        String TEST2_PROJ_GRP_DESCRIPTION = getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
+        String BUILD_POM_NAME = getProperty( "BUILD_POM_NAME" );
+        String BUILD_GOALS = getProperty( "BUILD_GOALS" );
+        String BUILD_ARGUMENTS = getProperty( "BUILD_ARGUMENTS" );
+        String BUILD_DESCRIPTION = getProperty( "BUILD_DESCRIPTION" );
         goToGroupBuildDefinitionPage( TEST2_PROJ_GRP_NAME, TEST2_PROJ_GRP_ID, TEST2_PROJ_GRP_DESCRIPTION );
         clickButtonWithValue( "Add" );
         addEditGroupBuildDefinition( TEST2_PROJ_GRP_NAME, BUILD_POM_NAME, BUILD_GOALS, BUILD_ARGUMENTS,
@@ -113,13 +113,13 @@ public class BuildDefinitionTest
     public void testAddNotDefautltGroupBuildDefinition()
         throws Exception
     {
-        String TEST2_PROJ_GRP_NAME = p.getProperty( "TEST2_PROJ_GRP_NAME" );
-        String TEST2_PROJ_GRP_ID = p.getProperty( "TEST2_PROJ_GRP_ID" );
-        String TEST2_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
-        String BUILD_POM_NAME = p.getProperty( "BUILD_POM_NAME" );
-        String BUILD_GOALS = p.getProperty( "BUILD_GOALS" );
-        String BUILD_ARGUMENTS = p.getProperty( "BUILD_ARGUMENTS" );
-        String BUILD_DESCRIPTION = p.getProperty( "BUILD_DESCRIPTION" );
+        String TEST2_PROJ_GRP_NAME = getProperty( "TEST2_PROJ_GRP_NAME" );
+        String TEST2_PROJ_GRP_ID = getProperty( "TEST2_PROJ_GRP_ID" );
+        String TEST2_PROJ_GRP_DESCRIPTION = getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
+        String BUILD_POM_NAME = getProperty( "BUILD_POM_NAME" );
+        String BUILD_GOALS = getProperty( "BUILD_GOALS" );
+        String BUILD_ARGUMENTS = getProperty( "BUILD_ARGUMENTS" );
+        String BUILD_DESCRIPTION = getProperty( "BUILD_DESCRIPTION" );
         goToGroupBuildDefinitionPage( TEST2_PROJ_GRP_NAME, TEST2_PROJ_GRP_ID, TEST2_PROJ_GRP_DESCRIPTION );
         clickButtonWithValue( "Add" );
         addEditGroupBuildDefinition( TEST2_PROJ_GRP_NAME, BUILD_POM_NAME, BUILD_GOALS, BUILD_ARGUMENTS,
@@ -130,13 +130,13 @@ public class BuildDefinitionTest
     public void testEditGroupBuildDefinition()
         throws Exception
     {
-        String TEST2_PROJ_GRP_NAME = p.getProperty( "TEST2_PROJ_GRP_NAME" );
-        String TEST2_PROJ_GRP_ID = p.getProperty( "TEST2_PROJ_GRP_ID" );
-        String TEST2_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
-        String BUILD_POM_NAME = p.getProperty( "BUILD_POM_NAME" );
-        String BUILD_GOALS = p.getProperty( "BUILD_GOALS" );
-        String BUILD_ARGUMENTS = p.getProperty( "BUILD_ARGUMENTS" );
-        String BUILD_DESCRIPTION = p.getProperty( "BUILD_DESCRIPTION" );
+        String TEST2_PROJ_GRP_NAME = getProperty( "TEST2_PROJ_GRP_NAME" );
+        String TEST2_PROJ_GRP_ID = getProperty( "TEST2_PROJ_GRP_ID" );
+        String TEST2_PROJ_GRP_DESCRIPTION = getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
+        String BUILD_POM_NAME = getProperty( "BUILD_POM_NAME" );
+        String BUILD_GOALS = getProperty( "BUILD_GOALS" );
+        String BUILD_ARGUMENTS = getProperty( "BUILD_ARGUMENTS" );
+        String BUILD_DESCRIPTION = getProperty( "BUILD_DESCRIPTION" );
         String newPom = "newpom.xml";
         String newGoals = "new goals";
         String newArguments = "new arguments";
@@ -154,11 +154,11 @@ public class BuildDefinitionTest
     public void testDeleteGroupBuildDefinition()
         throws Exception
     {
-        String TEST2_PROJ_GRP_NAME = p.getProperty( "TEST2_PROJ_GRP_NAME" );
-        String TEST2_PROJ_GRP_ID = p.getProperty( "TEST2_PROJ_GRP_ID" );
-        String TEST2_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
-        String BUILD_GOALS = p.getProperty( "BUILD_GOALS" );
-        String BUILD_DESCRIPTION = p.getProperty( "BUILD_DESCRIPTION" );
+        String TEST2_PROJ_GRP_NAME = getProperty( "TEST2_PROJ_GRP_NAME" );
+        String TEST2_PROJ_GRP_ID = getProperty( "TEST2_PROJ_GRP_ID" );
+        String TEST2_PROJ_GRP_DESCRIPTION = getProperty( "TEST2_PROJ_GRP_DESCRIPTION" );
+        String BUILD_GOALS = getProperty( "BUILD_GOALS" );
+        String BUILD_DESCRIPTION = getProperty( "BUILD_DESCRIPTION" );
         goToGroupBuildDefinitionPage( TEST2_PROJ_GRP_NAME, TEST2_PROJ_GRP_ID, TEST2_PROJ_GRP_DESCRIPTION );
         // Click in Delete Image
         clickLinkWithXPath( "(//a[contains(@href,'removeGroupBuildDefinition')])//img" );
@@ -171,12 +171,12 @@ public class BuildDefinitionTest
     public void testAddNotDefautltProjectBuildDefinition()
         throws Exception
     {
-        String TEST_PROJ_GRP_NAME = p.getProperty( "TEST_PROJ_GRP_NAME" );
-        String M2_PROJ_GRP_NAME = p.getProperty( "M2_PROJ_GRP_NAME" );
-        String BUILD_POM_NAME = p.getProperty( "BUILD_POM_NAME" );
-        String BUILD_GOALS = p.getProperty( "BUILD_GOALS" );
-        String BUILD_ARGUMENTS = p.getProperty( "BUILD_ARGUMENTS" );
-        String BUILD_DESCRIPTION = p.getProperty( "BUILD_DESCRIPTION" );
+        String TEST_PROJ_GRP_NAME = getProperty( "TEST_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_NAME = getProperty( "M2_PROJ_GRP_NAME" );
+        String BUILD_POM_NAME = getProperty( "BUILD_POM_NAME" );
+        String BUILD_GOALS = getProperty( "BUILD_GOALS" );
+        String BUILD_ARGUMENTS = getProperty( "BUILD_ARGUMENTS" );
+        String BUILD_DESCRIPTION = getProperty( "BUILD_DESCRIPTION" );
         goToProjectInformationPage( TEST_PROJ_GRP_NAME, M2_PROJ_GRP_NAME );
         clickLinkWithXPath( "//input[contains(@id,'buildDefinition')]" );
         addEditGroupBuildDefinition( null, BUILD_POM_NAME, BUILD_GOALS, BUILD_ARGUMENTS, BUILD_DESCRIPTION, false,
@@ -187,10 +187,10 @@ public class BuildDefinitionTest
     public void testDeleteProjectBuildDefinition()
         throws Exception
     {
-        String TEST_PROJ_GRP_NAME = p.getProperty( "TEST_PROJ_GRP_NAME" );
-        String M2_PROJ_GRP_NAME = p.getProperty( "M2_PROJ_GRP_NAME" );
-        String BUILD_GOALS = p.getProperty( "BUILD_GOALS" );
-        String BUILD_DESCRIPTION = p.getProperty( "BUILD_DESCRIPTION" );
+        String TEST_PROJ_GRP_NAME = getProperty( "TEST_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_NAME = getProperty( "M2_PROJ_GRP_NAME" );
+        String BUILD_GOALS = getProperty( "BUILD_GOALS" );
+        String BUILD_DESCRIPTION = getProperty( "BUILD_DESCRIPTION" );
         goToProjectInformationPage( TEST_PROJ_GRP_NAME, M2_PROJ_GRP_NAME );
         // Click in Delete Image
         clickLinkWithXPath( "(//a[contains(@href,'removeProjectBuildDefinition')])//img" );

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildDefinitionTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildDefinitionTest.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildEnvironmentTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildEnvironmentTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildEnvironmentTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/BuildEnvironmentTest.java Thu May  6 09:23:13 2010
@@ -32,9 +32,9 @@ public class BuildEnvironmentTest
 {
     public void testAddBuildEnvironment()
     {
-        String BUIL_ENV_NAME = p.getProperty( "BUIL_ENV_NAME" );
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
         goToAddBuildEnvironment();
-        addBuildEnvironment( BUIL_ENV_NAME, new String[] {}, true );
+        addBuildEnvironment( BUILD_ENV_NAME, new String[] {}, true );
     }
 
     public void testAddInvalidBuildEnvironment()
@@ -47,8 +47,8 @@ public class BuildEnvironmentTest
     @Test( dependsOnMethods = { "testAddBuildEnvironment" } )
     public void testEditInvalidBuildEnvironment()
     {
-        String BUIL_ENV_NAME = p.getProperty( "BUIL_ENV_NAME" );
-        goToEditBuildEnvironment( BUIL_ENV_NAME );
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
+        goToEditBuildEnvironment( BUILD_ENV_NAME );
         editBuildEnvironment( "", new String[] {}, false );
         assertTextPresent( "You must define a name" );
     }
@@ -56,29 +56,79 @@ public class BuildEnvironmentTest
     @Test( dependsOnMethods = { "testAddBuildEnvironment" } )
     public void testAddDuplicatedBuildEnvironment()
     {
-        String BUIL_ENV_NAME = p.getProperty( "BUIL_ENV_NAME" );
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
         goToAddBuildEnvironment();
-        addBuildEnvironment( BUIL_ENV_NAME, new String[] {}, false );
+        addBuildEnvironment( BUILD_ENV_NAME, new String[] {}, false );
         assertTextPresent( "A Build Environment with the same name already exists" );
     }
 
     @Test( dependsOnMethods = { "testAddBuildEnvironment" } )
     public void testEditBuildEnvironment()
     {
-        String BUIL_ENV_NAME = p.getProperty( "BUIL_ENV_NAME" );
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
         String newName = "new_name";
-        goToEditBuildEnvironment( BUIL_ENV_NAME );
+        goToEditBuildEnvironment( BUILD_ENV_NAME );
         editBuildEnvironment( newName, new String[] {}, true );
         // TODO: ADD INSTALLATIONS TO ENVIROTMENT
         goToEditBuildEnvironment( newName );
-        editBuildEnvironment( BUIL_ENV_NAME, new String[] {}, true );
+        editBuildEnvironment( BUILD_ENV_NAME, new String[] {}, true );
     }
 
     @Test( dependsOnMethods = { "testEditInvalidBuildEnvironment", "testEditBuildEnvironment",
         "testAddDuplicatedBuildEnvironment", "testEditInvalidBuildEnvironment" } )
     public void testDeleteBuildEnvironment()
     {
-        String BUIL_ENV_NAME = p.getProperty( "BUIL_ENV_NAME" );
-        removeBuildEnvironment( BUIL_ENV_NAME );
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
+        removeBuildEnvironment( BUILD_ENV_NAME );
+    }
+
+    @Test( dependsOnMethods = { "testDeleteBuildEnvironment", "testAddBuildAgentGroupWithEmptyBuildAgent" } )
+    public void testAddBuildEnvironmentWithBuildAgentGroup()
+    {
+        try
+        {
+            enableDistributedBuilds();
+
+            String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
+            String BUILD_AGENT_GROUPNAME = getProperty( "BUILD_AGENT_GROUPNAME" );
+            goToAddBuildEnvironment();
+            addBuildEnvironmentWithBuildAgentGroup( BUILD_ENV_NAME, new String[] {}, BUILD_AGENT_GROUPNAME, true );
+        }
+        finally
+        {
+            disableDistributedBuilds();
+        }
+    }
+    
+    @Test( dependsOnMethods = { "testAddBuildEnvironmentWithBuildAgentGroup" } )
+    public void testEditDuplicatedBuildEnvironmentParallelBuilds()
+    {
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
+        String newName = "NEW_BUILD_ENV";
+        goToAddBuildEnvironment();
+        addBuildEnvironment( newName, new String[] {}, true );
+        goToEditBuildEnvironment( newName );
+        editBuildEnvironment( BUILD_ENV_NAME, new String[] {}, false );
+        assertTextPresent( "A Build Environment with the same name already exists" );
+    }
+    
+    @Test( dependsOnMethods = { "testEditDuplicatedBuildEnvironmentParallelBuilds" } )
+    public void testEditDuplicatedBuildEnvironmentDistributedBuilds()
+    {
+    try
+        {
+            enableDistributedBuilds();
+
+            String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
+            String BUILD_AGENT_GROUPNAME = getProperty( "BUILD_AGENT_GROUPNAME" );
+            String newName = "NEW_BUILD_ENV";
+            goToEditBuildEnvironment( newName );
+            editBuildEnvironmentWithBuildAgentGroup( BUILD_ENV_NAME, new String[] {}, BUILD_AGENT_GROUPNAME, false );
+            assertTextPresent( "A Build Environment with the same name already exists" );
+        }
+        finally
+        {
+            disableDistributedBuilds();
+        }
     }
 }

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/ConfigurationTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/ConfigurationTest.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/InstallationTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/InstallationTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LocalRepositoriesTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LocalRepositoriesTest.java Thu May  6 09:23:13 2010
@@ -32,8 +32,8 @@ public class LocalRepositoriesTest
 {
     public void testAddLocalRepository()
     {
-        String LOCAL_REPOSITORY_NAME = p.getProperty( "LOCAL_REPOSITORY_NAME" );
-        String LOCAL_REPOSITORY_LOCATION = p.getProperty( "LOCAL_REPOSITORY_LOCATION" );
+        String LOCAL_REPOSITORY_NAME = getProperty( "LOCAL_REPOSITORY_NAME" );
+        String LOCAL_REPOSITORY_LOCATION = getProperty( "LOCAL_REPOSITORY_LOCATION" );
         goToAddLocalRepository();
         addEditLocalRepository( LOCAL_REPOSITORY_NAME, LOCAL_REPOSITORY_LOCATION, true );
     }
@@ -49,19 +49,30 @@ public class LocalRepositoriesTest
     @Test( dependsOnMethods = { "testAddLocalRepository" } )
     public void testAddDuplicatedLocalRepository()
     {
-        String LOCAL_REPOSITORY_NAME = p.getProperty( "LOCAL_REPOSITORY_NAME" );
-        String LOCAL_REPOSITORY_LOCATION = p.getProperty( "LOCAL_REPOSITORY_LOCATION" );
+        String LOCAL_REPOSITORY_NAME = getProperty( "LOCAL_REPOSITORY_NAME" );
+        String LOCAL_REPOSITORY_LOCATION = getProperty( "LOCAL_REPOSITORY_LOCATION" );
         goToAddLocalRepository();
         addEditLocalRepository( LOCAL_REPOSITORY_NAME, LOCAL_REPOSITORY_LOCATION, false );
         assertTextPresent( "Local repository name must be unique" );
         assertTextPresent( "Local repository location must be unique" );
     }
-
+    
     @Test( dependsOnMethods = { "testAddDuplicatedLocalRepository" } )
+    public void testAddDuplicateLocalRepositoryWithTrailingWhitespaces()
+    {
+        String duplicateRepositoryName = addTrailingWhitespace( getProperty( "LOCAL_REPOSITORY_NAME" ) );
+        String duplicateRepositoryLocation = addTrailingWhitespace( getProperty( "LOCAL_REPOSITORY_LOCATION" ) );
+        goToAddLocalRepository();
+        addEditLocalRepository( duplicateRepositoryName, duplicateRepositoryLocation, false );
+        assertTextPresent( "Local repository name must be unique" );
+        assertTextPresent( "Local repository location must be unique" );
+    }
+
+    @Test( dependsOnMethods = { "testAddDuplicateLocalRepositoryWithTrailingWhitespaces" } )
     public void testEditLocalRepository()
     {
-        String LOCAL_REPOSITORY_NAME = p.getProperty( "LOCAL_REPOSITORY_NAME" );
-        String LOCAL_REPOSITORY_LOCATION = p.getProperty( "LOCAL_REPOSITORY_LOCATION" );
+        String LOCAL_REPOSITORY_NAME = getProperty( "LOCAL_REPOSITORY_NAME" );
+        String LOCAL_REPOSITORY_LOCATION = getProperty( "LOCAL_REPOSITORY_LOCATION" );
         String newName = "new_name";
         String newLocation = "new_location";
         goToEditLocalRepository( LOCAL_REPOSITORY_NAME, LOCAL_REPOSITORY_LOCATION );
@@ -73,7 +84,13 @@ public class LocalRepositoriesTest
     @Test( dependsOnMethods = { "testEditLocalRepository" } )
     public void testDeleteLocalRepository()
     {
-        String LOCAL_REPOSITORY_NAME = p.getProperty( "LOCAL_REPOSITORY_NAME" );
+        String LOCAL_REPOSITORY_NAME = getProperty( "LOCAL_REPOSITORY_NAME" );
         removeLocalRepository( LOCAL_REPOSITORY_NAME );
     }
+
+    private String addTrailingWhitespace( String str )
+    {
+        String WHITESPACE = "    ";
+        return WHITESPACE.concat( str.concat( WHITESPACE ) );
+    }
 }

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LocalRepositoriesTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LocalRepositoriesTest.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LoginTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LoginTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LoginTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LoginTest.java Thu May  6 09:23:13 2010
@@ -20,8 +20,6 @@ package org.apache.continuum.web.test;
  */
 
 import org.apache.continuum.web.test.parent.AbstractContinuumTest;
-import org.testng.annotations.AfterTest;
-import org.testng.annotations.BeforeTest;
 import org.testng.annotations.Test;
 
 /*
@@ -31,7 +29,7 @@ import org.testng.annotations.Test;
  */
 /**
  * Based on LoginTest of Emmanuel Venisse test.
- * 
+ *
  * @author José Morales Martínez
  * @version $Id$
  */
@@ -43,7 +41,7 @@ public class LoginTest
     {
         goToLoginPage();
         getSelenium().type( "loginForm_username", "badUsername" );
-        getSelenium().type( "loginForm_username", p.getProperty( "ADMIN_PASSWORD" ) );
+        getSelenium().type( "loginForm_username", getProperty( "ADMIN_PASSWORD" ) );
         getSelenium().click( "loginForm__login" );
         getSelenium().waitForPageToLoad( maxWaitTimeInMs );
         assertTextPresent( "You have entered an incorrect username and/or password" );
@@ -53,7 +51,7 @@ public class LoginTest
     public void testWithBadPassword()
     {
         goToLoginPage();
-        getSelenium().type( "loginForm_username", p.getProperty( "ADMIN_USERNAME" ) );
+        getSelenium().type( "loginForm_username", getProperty( "ADMIN_USERNAME" ) );
         getSelenium().type( "loginForm_password", "badPassword" );
         getSelenium().click( "loginForm__login" );
         getSelenium().waitForPageToLoad( maxWaitTimeInMs );
@@ -74,7 +72,7 @@ public class LoginTest
     public void testWithEmptyPassword()
     {
         goToLoginPage();
-        getSelenium().type( "loginForm_username", p.getProperty( "ADMIN_USERNAME" ) );
+        getSelenium().type( "loginForm_username", getProperty( "ADMIN_USERNAME" ) );
         getSelenium().click( "loginForm__login" );
         getSelenium().waitForPageToLoad( maxWaitTimeInMs );
         assertTextPresent( "You have entered an incorrect username and/or password" );
@@ -84,27 +82,12 @@ public class LoginTest
     public void testWithCorrectUsernamePassword()
     {
         goToLoginPage();
-        getSelenium().type( "loginForm_username", p.getProperty( "ADMIN_USERNAME" ) );
-        getSelenium().type( "loginForm_password", p.getProperty( "ADMIN_PASSWORD" ) );
+        getSelenium().type( "loginForm_username", getProperty( "ADMIN_USERNAME" ) );
+        getSelenium().type( "loginForm_password", getProperty( "ADMIN_PASSWORD" ) );
         getSelenium().click( "loginForm__login" );
         getSelenium().waitForPageToLoad( maxWaitTimeInMs );
         assertTextPresent( "Edit Details" );
         assertTextPresent( "Logout" );
-        assertTextPresent( p.getProperty( "ADMIN_USERNAME" ) );
-    }
-
-    @BeforeTest
-    public void open()
-        throws Exception
-    {
-        super.open();
-    }
-
-    @Override
-    @AfterTest
-    public void close()
-        throws Exception
-    {
-        super.close();
+        assertTextPresent( getProperty( "ADMIN_USERNAME" ) );
     }
 }

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LoginTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LoginTest.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenOneProjectTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenOneProjectTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenOneProjectTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenOneProjectTest.java Thu May  6 09:23:13 2010
@@ -24,7 +24,7 @@ import org.testng.annotations.Test;
 
 /**
  * Based on AddMavenOneProjectTestCase of Emmanuel Venisse.
- * 
+ *
  * @author José Morales Martínez
  * @version $Id$
  */
@@ -32,18 +32,42 @@ import org.testng.annotations.Test;
 public class MavenOneProjectTest
     extends AbstractContinuumTest
 {
+    public void testAddMavenOneProjectWithNoDefaultBuildDefinitionFromTemplate()
+        throws Exception
+    {
+        String M1_POM_URL = getProperty( "M1_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
+        String M1_PROJ_GRP_NAME = getProperty( "M1_PROJ_GRP_NAME" );
+        String M1_PROJ_GRP_ID = getProperty( "M1_PROJ_GRP_ID" );
+        String M1_PROJ_GRP_DESCRIPTION = getProperty( "M1_PROJ_GRP_DESCRIPTION" );
+
+        removeDefaultBuildDefinitionFromTemplate( "maven1" );
+        
+        goToAddMavenOneProjectPage();
+        addMavenOneProject( M1_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, null, null, true );
+        assertProjectGroupSummaryPage( M1_PROJ_GRP_NAME, M1_PROJ_GRP_ID, M1_PROJ_GRP_DESCRIPTION );
+
+        // Delete project group
+        removeProjectGroup( M1_PROJ_GRP_NAME );
+
+        // Re-add default build definition of template
+        addDefaultBuildDefinitionFromTemplate( "maven1" );
+    }
+
     /**
      * test with valid pom url
      */
+    @Test( dependsOnMethods = { "testAddMavenOneProjectWithNoDefaultBuildDefinitionFromTemplate" } )
     public void testValidPomUrl()
         throws Exception
     {
-        String M1_POM_URL = p.getProperty( "M1_POM_URL" );
-        String M1_POM_USERNAME = p.getProperty( "M1_POM_USERNAME" );
-        String M1_POM_PASSWORD = p.getProperty( "M1_POM_PASSWORD" );
-        String M1_PROJ_GRP_NAME = p.getProperty( "M1_PROJ_GRP_NAME" );
-        String M1_PROJ_GRP_ID = p.getProperty( "M1_PROJ_GRP_ID" );
-        String M1_PROJ_GRP_DESCRIPTION = p.getProperty( "M1_PROJ_GRP_DESCRIPTION" );
+        String M1_POM_URL = getProperty( "M1_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
+        String M1_PROJ_GRP_NAME = getProperty( "M1_PROJ_GRP_NAME" );
+        String M1_PROJ_GRP_ID = getProperty( "M1_PROJ_GRP_ID" );
+        String M1_PROJ_GRP_DESCRIPTION = getProperty( "M1_PROJ_GRP_DESCRIPTION" );
         // Enter values into Add Maven Two Project fields, and submit
         goToAddMavenOneProjectPage();
         addMavenOneProject( M1_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, null, null, true );
@@ -54,12 +78,12 @@ public class MavenOneProjectTest
     public void testAddMavenOneProjectFromRemoteSourceToNonDefaultProjectGroup()
         throws Exception
     {
-        String TEST_PROJ_GRP_NAME = p.getProperty( "TEST_PROJ_GRP_NAME" );
-        String TEST_PROJ_GRP_ID = p.getProperty( "TEST_PROJ_GRP_ID" );
-        String TEST_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST_PROJ_GRP_DESCRIPTION" );
-        String M1_POM_URL = p.getProperty( "M1_POM_URL" );
-        String M1_POM_USERNAME = p.getProperty( "M1_POM_USERNAME" );
-        String M1_POM_PASSWORD = p.getProperty( "M1_POM_PASSWORD" );
+        String TEST_PROJ_GRP_NAME = getProperty( "TEST_PROJ_GRP_NAME" );
+        String TEST_PROJ_GRP_ID = getProperty( "TEST_PROJ_GRP_ID" );
+        String TEST_PROJ_GRP_DESCRIPTION = getProperty( "TEST_PROJ_GRP_DESCRIPTION" );
+        String M1_POM_URL = getProperty( "M1_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
         goToAddMavenOneProjectPage();
         addMavenOneProject( M1_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, TEST_PROJ_GRP_NAME, null, true );
         assertProjectGroupSummaryPage( TEST_PROJ_GRP_NAME, TEST_PROJ_GRP_ID, TEST_PROJ_GRP_DESCRIPTION );
@@ -82,9 +106,9 @@ public class MavenOneProjectTest
     public void testMissingElementInPom()
         throws Exception
     {
-        String M1_MISS_REPO_POM_URL = p.getProperty( "M1_MISS_REPO_POM_URL" );
-        String M1_POM_USERNAME = p.getProperty( "M1_POM_USERNAME" );
-        String M1_POM_PASSWORD = p.getProperty( "M1_POM_PASSWORD" );
+        String M1_MISS_REPO_POM_URL = getProperty( "M1_MISS_REPO_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
         goToAddMavenOneProjectPage();
         addMavenOneProject( M1_MISS_REPO_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, null, null, false );
         assertTextPresent( "Missing 'repository' element in the POM." );
@@ -96,9 +120,9 @@ public class MavenOneProjectTest
     public void testWithExtendElementPom()
         throws Exception
     {
-        String M1_EXTENDED_POM_URL = p.getProperty( "M1_EXTENDED_POM_URL" );
-        String M1_POM_USERNAME = p.getProperty( "M1_POM_USERNAME" );
-        String M1_POM_PASSWORD = p.getProperty( "M1_POM_PASSWORD" );
+        String M1_EXTENDED_POM_URL = getProperty( "M1_EXTENDED_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
         goToAddMavenOneProjectPage();
         addMavenOneProject( M1_EXTENDED_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, null, null, false );
         assertTextPresent( "Cannot use a POM with an 'extend' element" );
@@ -110,9 +134,9 @@ public class MavenOneProjectTest
     public void testUnparseableXmlContent()
         throws Exception
     {
-        String M1_UNPARSEABLE_POM_URL = p.getProperty( "M1_UNPARSEABLE_POM_URL" );
-        String M1_POM_USERNAME = p.getProperty( "M1_POM_USERNAME" );
-        String M1_POM_PASSWORD = p.getProperty( "M1_POM_PASSWORD" );
+        String M1_UNPARSEABLE_POM_URL = getProperty( "M1_UNPARSEABLE_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
         goToAddMavenOneProjectPage();
         addMavenOneProject( M1_UNPARSEABLE_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, null, null, false );
         assertTextPresent( "The XML content of the POM can not be parsed." );
@@ -136,7 +160,7 @@ public class MavenOneProjectTest
     public void testInaccessiblePomUrl()
         throws Exception
     {
-        String pomUrl = "http://www.google.com";
+        String pomUrl = "http://localhost:9595/";
         goToAddMavenOneProjectPage();
         addMavenOneProject( pomUrl, "", "", null, null, false );
         assertTextPresent( "POM file does not exist. Either the POM you specified or one of its modules does not exist." );
@@ -152,4 +176,64 @@ public class MavenOneProjectTest
         clickButtonWithValue( "Cancel" );
         assertAboutPage();
     }
+
+    @Test( dependsOnMethods = { "testValidPomUrl" } )
+    public void testDeleteMavenOneProject()
+        throws Exception
+    {
+        boolean isExisting = false;
+        String M1_PROJ_GRP_NAME = getProperty( "M1_DELETE_PROJ_GRP_NAME" );
+        goToProjectGroupsSummaryPage();
+        
+        if ( isLinkPresent( M1_PROJ_GRP_NAME ) )
+        {
+            isExisting = true;
+        }
+        else
+        {
+            addMaven1Project( M1_PROJ_GRP_NAME );
+        }
+        
+        // delete project - delete icon
+        clickLinkWithText( M1_PROJ_GRP_NAME );
+        clickLinkWithXPath( "//tbody/tr['0']/td['10']/a/img[@alt='Delete']" );
+        assertTextPresent( "Delete Continuum Project" );
+        clickButtonWithValue( "Delete" );
+        assertPage( "Continuum - Project Group" );
+        assertLinkNotPresent( M1_PROJ_GRP_NAME );
+        
+        // remove group for next test
+        removeProjectGroup( M1_PROJ_GRP_NAME );
+        
+        // delete project - "Delete Project(s)" button
+        addMaven1Project( M1_PROJ_GRP_NAME );
+        clickLinkWithText( M1_PROJ_GRP_NAME );
+        checkField( "//tbody/tr['0']/td['0']/input[@name='selectedProjects']" );
+        clickButtonWithValue( "Delete Project(s)" );
+        assertTextPresent( "Delete Continuum Projects" );
+        clickButtonWithValue( "Delete" );
+        assertPage( "Continuum - Project Group" );
+        assertLinkNotPresent( M1_PROJ_GRP_NAME );
+        
+        if ( !isExisting )
+        {
+            removeProjectGroup( M1_PROJ_GRP_NAME );
+        }
+    }
+    
+    private void addMaven1Project( String groupName )
+        throws Exception
+    {
+        String M1_POM_URL = getProperty( "M1_DELETE_POM_URL" );
+        String M1_POM_USERNAME = getProperty( "M1_POM_USERNAME" );
+        String M1_POM_PASSWORD = getProperty( "M1_POM_PASSWORD" );
+        String M1_PROJ_GRP_ID = getProperty( "M1_DELETE_PROJ_GRP_ID" );
+        String M1_PROJ_GRP_DESCRIPTION = getProperty( "M1_DELETE_PROJ_GRP_DESCRIPTION" );
+        
+        goToAddMavenOneProjectPage();
+        assertLinkNotPresent( groupName );
+        addMavenOneProject( M1_POM_URL, M1_POM_USERNAME, M1_POM_PASSWORD, null, null, true );
+        goToProjectGroupsSummaryPage();
+        assertLinkPresent( groupName );
+    }
 }

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenTwoProjectTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenTwoProjectTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenTwoProjectTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenTwoProjectTest.java Thu May  6 09:23:13 2010
@@ -24,7 +24,7 @@ import org.testng.annotations.Test;
 
 /**
  * Based on AddMavenTwoProjectTest of Emmanuel Venisse test.
- * 
+ *
  * @author José Morales Martínez
  * @version $Id$
  */
@@ -33,36 +33,95 @@ public class MavenTwoProjectTest
     extends AbstractContinuumTest
 {
 
+    public void testAddMavenTwoProjectWithNoDefaultBuildDefinitionInTemplate()
+        throws Exception
+    {
+        String M2_POM_URL = getProperty( "M2_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+
+        String M2_PROJ_GRP_NAME = getProperty( "M2_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_PROJ_GRP_ID" );
+        String M2_PROJ_GRP_DESCRIPTION = getProperty( "M2_PROJ_GRP_DESCRIPTION" );
+        String M2_PROJ_GRP_SCM_ROOT_URL = getProperty( "M2_PROJ_GRP_SCM_ROOT_URL" );
+
+        removeDefaultBuildDefinitionFromTemplate( "maven2" );
+
+        addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, null, true );
+
+        assertProjectGroupSummaryPage( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION );
+
+        assertTextPresent( M2_PROJ_GRP_SCM_ROOT_URL );
+
+        // Delete project group
+        removeProjectGroup( M2_PROJ_GRP_NAME );
+
+        // Re-add default build definition of template
+        addDefaultBuildDefinitionFromTemplate( "maven2" );
+    }
+
+    @Test( dependsOnMethods = { "testAddMavenTwoProjectWithNoDefaultBuildDefinitionInTemplate" } )
     public void testAddMavenTwoProject()
         throws Exception
     {
-        String M2_POM_URL = p.getProperty( "M2_POM_URL" );
-        String M2_POM_USERNAME = p.getProperty( "M2_POM_USERNAME" );
-        String M2_POM_PASSWORD = p.getProperty( "M2_POM_PASSWORD" );
-
-        String M2_PROJ_GRP_NAME = p.getProperty( "M2_PROJ_GRP_NAME" );
-        String M2_PROJ_GRP_ID = p.getProperty( "M2_PROJ_GRP_ID" );
-        String M2_PROJ_GRP_DESCRIPTION = p.getProperty( "M2_PROJ_GRP_DESCRIPTION" );
+        String M2_POM_URL = getProperty( "M2_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+
+        String M2_PROJ_GRP_NAME = getProperty( "M2_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_PROJ_GRP_ID" );
+        String M2_PROJ_GRP_DESCRIPTION = getProperty( "M2_PROJ_GRP_DESCRIPTION" );
+        String M2_PROJ_GRP_SCM_ROOT_URL = getProperty( "M2_PROJ_GRP_SCM_ROOT_URL" );
+        
         // Enter values into Add Maven Two Project fields, and submit
         addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, null, true );
         // Wait Struct Listener
         assertProjectGroupSummaryPage( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION );
+
+        assertTextPresent( M2_PROJ_GRP_SCM_ROOT_URL );
+    }
+
+    /**
+     * Test flat multi module project with names that start with the same letter
+     */
+    public void testAddMavenTwoProjectModuleNameWithSameLetter()
+        throws Exception
+    {
+        String M2_POM_URL = getProperty( "M2_SAME_LETTER_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+
+        String M2_PROJ_GRP_NAME = getProperty( "M2_SAME_LETTER_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_SAME_LETTER_PROJ_GRP_ID" );
+        String M2_PROJ_GRP_DESCRIPTION = getProperty( "M2_SAME_LETTER_PROJ_GRP_DESCRIPTION" );
+
+        String M2_PROJ_GRP_SCM_ROOT_URL = getProperty( "M2_SAME_LETTER_PROJ_GRP_SCM_ROOT_URL" );
+
+        addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, null, true );
+
+        assertProjectGroupSummaryPage( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION );
+
+        assertTextPresent( M2_PROJ_GRP_SCM_ROOT_URL );
     }
 
     @Test( dependsOnMethods = { "testAddProjectGroup" } )
     public void testAddMavenTwoProjectFromRemoteSourceToNonDefaultProjectGroup()
         throws Exception
     {
-        String TEST_PROJ_GRP_NAME = p.getProperty( "TEST_PROJ_GRP_NAME" );
-        String TEST_PROJ_GRP_ID = p.getProperty( "TEST_PROJ_GRP_ID" );
-        String TEST_PROJ_GRP_DESCRIPTION = p.getProperty( "TEST_PROJ_GRP_DESCRIPTION" );
-
-        String M2_POM_URL = p.getProperty( "M2_POM_URL" );
-        String M2_POM_USERNAME = p.getProperty( "M2_POM_USERNAME" );
-        String M2_POM_PASSWORD = p.getProperty( "M2_POM_PASSWORD" );
+        String TEST_PROJ_GRP_NAME = getProperty( "TEST_PROJ_GRP_NAME" );
+        String TEST_PROJ_GRP_ID = getProperty( "TEST_PROJ_GRP_ID" );
+        String TEST_PROJ_GRP_DESCRIPTION = getProperty( "TEST_PROJ_GRP_DESCRIPTION" );
+        String TEST_PROJ_GRP_SCM_ROOT_URL = getProperty( "M2_PROJ_GRP_SCM_ROOT_URL" );
+
+        String M2_POM_URL = getProperty( "M2_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+        
         addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, TEST_PROJ_GRP_NAME, true );
 
         assertProjectGroupSummaryPage( TEST_PROJ_GRP_NAME, TEST_PROJ_GRP_ID, TEST_PROJ_GRP_DESCRIPTION );
+
+        assertTextPresent( TEST_PROJ_GRP_SCM_ROOT_URL );
     }
 
     /**
@@ -81,7 +140,7 @@ public class MavenTwoProjectTest
     public void testMissingScmElementPom()
         throws Exception
     {
-        String pomUrl = p.getProperty( "NOT_SCM_POM_URL" );
+        String pomUrl = getProperty( "NOT_SCM_POM_URL" );
         submitAddMavenTwoProjectPage( pomUrl, false );
         assertTextPresent( "Missing ''scm'' element in the POM, project Maven Two Project" );
     }
@@ -103,7 +162,7 @@ public class MavenTwoProjectTest
     public void testMissingConnectionElement()
         throws Exception
     {
-        String pomUrl = p.getProperty( "MISS_CONECT_POM_URL" );
+        String pomUrl = getProperty( "MISS_CONECT_POM_URL" );
         submitAddMavenTwoProjectPage( pomUrl, false );
         assertTextPresent( "Missing 'connection' sub-element in the 'scm' element in the POM." );
     }
@@ -125,7 +184,7 @@ public class MavenTwoProjectTest
     public void testMissingParentPom()
         throws Exception
     {
-        String pomUrl = p.getProperty( "MISS_PARENT_POM_URL" );
+        String pomUrl = getProperty( "MISS_PARENT_POM_URL" );
         submitAddMavenTwoProjectPage( pomUrl, false );
         assertTextPresent( "Missing artifact trying to build the POM. Check that its parent POM is available or add it first in Continuum." );
     }
@@ -136,7 +195,7 @@ public class MavenTwoProjectTest
     public void testMissingModules()
         throws Exception
     {
-        String pomUrl = p.getProperty( "MISS_SUBPRO_POM_URL" );
+        String pomUrl = getProperty( "MISS_SUBPRO_POM_URL" );
         submitAddMavenTwoProjectPage( pomUrl, false );
         assertTextPresent( "Unknown error trying to build POM." );
     }
@@ -147,7 +206,7 @@ public class MavenTwoProjectTest
     public void testInaccessiblePomUrl()
         throws Exception
     {
-        String pomUrl = "http://www.google.com";
+        String pomUrl = "http://localhost:9595/";
         submitAddMavenTwoProjectPage( pomUrl, false );
         assertTextPresent( "POM file does not exist. Either the POM you specified or one of its modules does not exist." );
     }
@@ -162,4 +221,212 @@ public class MavenTwoProjectTest
         clickButtonWithValue( "Cancel" );
         assertAboutPage();
     }
+
+    @Test( dependsOnMethods = { "testAddMavenTwoProject" } )
+    public void testDeleteMavenTwoProject()
+        throws Exception
+    {
+        String M2_PROJ_GRP_NAME = getProperty( "M2_DELETE_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_SCM_ROOT_URL = getProperty( "M2_DELETE_PROJ_GRP_SCM_ROOT_URL" );
+        goToProjectGroupsSummaryPage();
+        
+        // delete project - delete icon
+        addMaven2Project( M2_PROJ_GRP_NAME );
+        clickLinkWithText( M2_PROJ_GRP_NAME );
+
+        assertPage( "Continuum - Project Group" );
+        assertTextPresent( M2_PROJ_GRP_SCM_ROOT_URL );
+
+        // TODO: this doesn't always seem to work, perhaps because of changes in the way icons are displayed
+        // wait for project to finish checkout
+        waitForProjectCheckout();
+
+        clickLinkWithXPath( "//tbody/tr['0']/td['10']/a/img[@alt='Delete']" );
+        assertTextPresent( "Delete Continuum Project" );
+        clickButtonWithValue( "Delete" );
+        assertPage( "Continuum - Project Group" );
+        assertTextNotPresent( "Unable to delete project" );
+        assertLinkNotPresent( M2_PROJ_GRP_NAME );
+        assertTextNotPresent( M2_PROJ_GRP_SCM_ROOT_URL );
+
+        // remove group for next test
+        removeProjectGroup( M2_PROJ_GRP_NAME );
+        assertLinkNotPresent( M2_PROJ_GRP_NAME );
+
+        // delete project - "Delete Project(s)" button
+        addMaven2Project( M2_PROJ_GRP_NAME );
+        clickLinkWithText( M2_PROJ_GRP_NAME );
+
+        assertPage( "Continuum - Project Group" );
+        //wait for project to finish checkout
+        waitForProjectCheckout();
+
+        checkField( "//tbody/tr['0']/td['0']/input[@name='selectedProjects']" );
+        clickButtonWithValue( "Delete Project(s)" );
+        assertTextPresent( "Delete Continuum Projects" );
+        clickButtonWithValue( "Delete" );
+        assertPage( "Continuum - Project Group" );
+        assertTextNotPresent( "Unable to delete project" );
+        assertLinkNotPresent( M2_PROJ_GRP_NAME );
+        assertTextNotPresent( M2_PROJ_GRP_SCM_ROOT_URL );
+
+        // remove project group
+        removeProjectGroup( M2_PROJ_GRP_NAME );
+        assertLinkNotPresent( M2_PROJ_GRP_NAME );
+    }
+
+    public void testBuildProjectGroupNoBuildAgentConfigured()
+        throws Exception
+    {
+        String M2_PROJ_GRP_NAME = getProperty( "M2_DELETE_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_DELETE_PROJ_GRP_ID" );
+    
+        try
+        {
+            enableDistributedBuilds();
+            addMaven2Project( M2_PROJ_GRP_NAME );
+            clickLinkWithText( M2_PROJ_GRP_NAME );
+    
+            assertPage( "Continuum - Project Group" );
+    
+            showProjectGroup( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, "" );
+            clickButtonWithValue( "Build all projects" );
+
+            assertTextPresent( "Unable to build projects because no build agent is configured" );
+
+            removeProjectGroup( M2_PROJ_GRP_NAME );
+            assertLinkNotPresent( M2_PROJ_GRP_NAME );
+        }
+        finally
+        {
+            disableDistributedBuilds();
+        }
+    }
+
+    @Test( dependsOnMethods = { "testDeleteMavenTwoProject", "testAddBuildAgent" } )
+    public void testProjectGroupAllBuildSuccessWithDistributedBuilds()
+        throws Exception
+    {
+        String M2_PROJ_GRP_NAME = getProperty( "M2_DELETE_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_DELETE_PROJ_GRP_ID" );
+
+        try
+        {
+            enableDistributedBuilds();
+
+            addMaven2Project( M2_PROJ_GRP_NAME );
+            clickLinkWithText( M2_PROJ_GRP_NAME );
+    
+            assertPage( "Continuum - Project Group" );
+    
+            showProjectGroup( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, "" );
+            clickButtonWithValue( "Build all projects" );
+
+            buildProjectGroup( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, "", M2_PROJ_GRP_NAME );
+        }
+        finally
+        {
+            disableDistributedBuilds();   
+        }
+    }
+
+    @Test( dependsOnMethods = { "testAddBuildAgentGroupWithEmptyBuildAgent", "testAddBuildEnvironmentWithBuildAgentGroup" } )
+    public void testProjectGroupNoBuildAgentConfiguredInBuildAgentGroup()
+        throws Exception
+    {
+        String M2_PROJ_GRP_NAME = getProperty( "M2_DELETE_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_DELETE_PROJ_GRP_ID" );
+        String BUILD_ENV_NAME = getProperty( "BUILD_ENV_NAME" );
+
+        try
+        {
+            enableDistributedBuilds();
+            addMaven2Project( M2_PROJ_GRP_NAME );
+            clickLinkWithText( M2_PROJ_GRP_NAME );
+
+            assertPage( "Continuum - Project Group" );
+
+            goToGroupBuildDefinitionPage( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, "" );
+            clickImgWithAlt( "Edit" );
+            assertAddEditBuildDefinitionPage();
+            selectValue( "profileId", BUILD_ENV_NAME );
+            submit();
+            assertGroupBuildDefinitionPage( M2_PROJ_GRP_NAME );
+
+            clickLinkWithText( "Project Group Summary" );
+            clickButtonWithValue( "Build all projects" );
+
+            assertTextPresent( "Unable to build projects because no build agent is configured in the build agent group" );
+
+            removeProjectGroup( M2_PROJ_GRP_NAME );
+            assertLinkNotPresent( M2_PROJ_GRP_NAME );
+        }
+        finally
+        {
+            disableDistributedBuilds();
+        }
+    }
+
+    public void testBuildMaven2ProjectWithTag()
+        throws Exception
+    {
+        String M2_POM_URL = getProperty( "M2_PROJ_WITH_TAG_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+    
+        String M2_PROJ_GRP_NAME = getProperty( "M2_PROJ_WITH_TAG_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_PROJ_WITH_TAG_PROJ_GRP_ID" );
+        String M2_PROJ_GRP_DESCRIPTION = "";
+    
+        addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, null, true );
+        assertProjectGroupSummaryPage( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION );
+    
+        buildProjectGroup( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION, M2_PROJ_GRP_NAME );
+    
+        removeProjectGroup( M2_PROJ_GRP_NAME );
+        assertLinkNotPresent( M2_PROJ_GRP_NAME );
+    }
+    
+    @Test( dependsOnMethods = { "testAddBuildAgent" } )
+    public void testBuildMaven2ProjectWithTagDistributedBuild()
+        throws Exception
+    {
+        String M2_POM_URL = getProperty( "M2_PROJ_WITH_TAG_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+    
+        String M2_PROJ_GRP_NAME = getProperty( "M2_PROJ_WITH_TAG_PROJ_GRP_NAME" );
+        String M2_PROJ_GRP_ID = getProperty( "M2_PROJ_WITH_TAG_PROJ_GRP_ID" );
+        String M2_PROJ_GRP_DESCRIPTION = "";
+    
+        try
+        {
+            enableDistributedBuilds();
+        
+            addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, null, true );
+            assertProjectGroupSummaryPage( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION );
+        
+            buildProjectGroup( M2_PROJ_GRP_NAME, M2_PROJ_GRP_ID, M2_PROJ_GRP_DESCRIPTION, M2_PROJ_GRP_NAME );
+        
+            removeProjectGroup( M2_PROJ_GRP_NAME );
+            assertLinkNotPresent( M2_PROJ_GRP_NAME );
+        }
+        finally
+        {
+            disableDistributedBuilds();
+        }
+    }
+
+    private void addMaven2Project( String groupName )
+        throws Exception
+    {
+        String M2_POM_URL = getProperty( "M2_DELETE_POM_URL" );
+        String M2_POM_USERNAME = getProperty( "M2_POM_USERNAME" );
+        String M2_POM_PASSWORD = getProperty( "M2_POM_PASSWORD" );
+        String M2_PROJ_GRP_DESCRIPTION = getProperty( "M2_DELETE_PROJ_GRP_DESCRIPTION" );
+        
+        addMavenTwoProject( M2_POM_URL, M2_POM_USERNAME, M2_POM_PASSWORD, null, true );
+        goToProjectGroupsSummaryPage();
+        assertLinkPresent( groupName );
+    }
 }

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenTwoProjectTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MavenTwoProjectTest.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MyAccountTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MyAccountTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MyAccountTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MyAccountTest.java Thu May  6 09:23:13 2010
@@ -25,7 +25,7 @@ import org.testng.annotations.Test;
 
 /**
  * Based on MyAccountTest of Emmanuel Venisse test.
- * 
+ *
  * @author José Morales Martínez
  * @version $Id$
  */
@@ -51,11 +51,11 @@ public class MyAccountTest
         clickLinkWithText( "Edit Details" );
         assertFieldValue( newFullName, "user.fullName" );
         assertFieldValue( newEmail, "user.email" );
-        setFieldValue( "user.fullName", p.getProperty( "ADMIN_USERNAME" ) );
+        setFieldValue( "user.fullName", getProperty( "ADMIN_USERNAME" ) );
         setFieldValue( "user.email", email );
         submit();
         clickLinkWithText( "Edit Details" );
-        assertFieldValue( p.getProperty( "ADMIN_USERNAME" ), "user.fullName" );
+        assertFieldValue( getProperty( "ADMIN_USERNAME" ), "user.fullName" );
         assertFieldValue( email, "user.email" );
     }
 }

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MyAccountTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/MyAccountTest.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"
--- continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/InstallationTest.java (original)
+++ continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/InstallationTest.java Thu May  6 09:23:13 2010
@@ -30,36 +30,37 @@ import org.testng.annotations.Test;
 public class InstallationTest
     extends AbstractInstallationTest
 {
-    public void testAddJdkToolWithoutBuildEnvirotment()
+    public void testAddJdkToolWithoutBuildEnvironment()
     {
-        String INSTALL_TOOL_JDK_NAME = p.getProperty( "INSTALL_TOOL_JDK_NAME" );
-        String INSTALL_TOOL_JDK_PATH = p.getProperty( "INSTALL_TOOL_JDK_PATH" );
-        goToAddInstallationTool();
-        addInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, false, true, true );
+        String INSTALL_TOOL_JDK_NAME = getProperty( "INSTALL_TOOL_JDK_NAME" );
+		String INSTALL_TOOL_JDK_PATH = isWindows() ? getProperty( "INSTALL_TOOL_JDK_PATH" ) :  getEscapeProperty( "INSTALL_TOOL_JDK_PATH" );
+		goToAddInstallationTool();
+		addInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, false, true, true );
     }
 
-    public void testAddMavenToolWithBuildEnvirotment()
+    public void testAddMavenToolWithBuildEnvironment()
     {
-        String INTALLA_TOOL_MAVEN_NAME = p.getProperty( "INTALLA_TOOL_MAVEN_NAME" );
-        String INTALLA_TOOL_MAVEN_PATH = p.getProperty( "INTALLA_TOOL_MAVEN_PATH" );
-        goToAddInstallationTool();
-        addInstallation( INTALLA_TOOL_MAVEN_NAME, "Maven 2", INTALLA_TOOL_MAVEN_PATH, true, true, true );
-        // TODO: Validate build envirotment
+        String INSTALL_TOOL_MAVEN_NAME = getProperty( "INSTALL_TOOL_MAVEN_NAME" );
+		String INSTALL_TOOL_MAVEN_PATH = isWindows() ? getProperty( "INSTALL_TOOL_MAVEN_PATH" ) :  getEscapeProperty( "INSTALL_TOOL_MAVEN_PATH" );
+		goToAddInstallationTool();
+		addInstallation( INSTALL_TOOL_MAVEN_NAME, "Maven 2", INSTALL_TOOL_MAVEN_PATH, true, true, true );
+		// TODO: Validate build environment
+		
     }
 
-    public void testAddInstallationVariableWithBuildEnvirotment()
+    public void testAddInstallationVariableWithBuildEnvironment()
     {
-        String INSTALL_VAR_NAME = p.getProperty( "INSTALL_VAR_NAME" );
-        String INSTALL_VAR_VARIABLE_NAME = p.getProperty( "INSTALL_VAR_VARIABLE_NAME" );
-        String INSTALL_VAR_PATH = p.getProperty( "INSTALL_VAR_PATH" );
+        String INSTALL_VAR_NAME = getProperty( "INSTALL_VAR_NAME" );
+        String INSTALL_VAR_VARIABLE_NAME = getProperty( "INSTALL_VAR_VARIABLE_NAME" );
+        String INSTALL_VAR_PATH = getProperty( "INSTALL_VAR_PATH" );
         goToAddInstallationVariable();
         addInstallation( INSTALL_VAR_NAME, INSTALL_VAR_VARIABLE_NAME, INSTALL_VAR_PATH, true, false, true );
         // TODO: Validate build envirotment
     }
 
-    public void testAddInstallationVariableWithoutBuildEnvirotment()
+    public void testAddInstallationVariableWithoutBuildEnvironment()
     {
-        String INSTALL_VAR_NAME = "var_without_build_envirotment";
+        String INSTALL_VAR_NAME = "var_without_build_environment";
         String INSTALL_VAR_VARIABLE_NAME = "var_name";
         String INSTALL_VAR_PATH = "path";
         goToAddInstallationVariable();
@@ -96,45 +97,46 @@ public class InstallationTest
         assertTextPresent( "You must define an environment variable" );
     }
 
-    @Test( dependsOnMethods = { "testAddJdkToolWithoutBuildEnvirotment" } )
+    @Test( dependsOnMethods = { "testAddJdkToolWithoutBuildEnvironment" } )
     public void testAddDuplicatedInstallationTool()
     {
-        String INSTALL_TOOL_JDK_NAME = p.getProperty( "INSTALL_TOOL_JDK_NAME" );
-        String INSTALL_TOOL_JDK_PATH = p.getProperty( "INSTALL_TOOL_JDK_PATH" );
-        goToAddInstallationTool();
-        addInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, false, true, false );
-        assertTextPresent( "Installation name already exists" );
+        String INSTALL_TOOL_JDK_NAME = getProperty( "INSTALL_TOOL_JDK_NAME" );
+		String INSTALL_TOOL_JDK_PATH = isWindows() ? getProperty( "INSTALL_TOOL_JDK_PATH" ) :  getEscapeProperty( "INSTALL_TOOL_JDK_PATH" );
+		goToAddInstallationTool();
+		addInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, false, true, false );
+		assertTextPresent( "Installation name already exists" );
+		
     }
 
-    @Test( dependsOnMethods = { "testAddInstallationVariableWithBuildEnvirotment" } )
+    @Test( dependsOnMethods = { "testAddInstallationVariableWithBuildEnvironment" } )
     public void testAddDuplicatedInstallationVariable()
     {
-        String INSTALL_VAR_NAME = p.getProperty( "INSTALL_VAR_NAME" );
-        String INSTALL_VAR_VARIABLE_NAME = p.getProperty( "INSTALL_VAR_VARIABLE_NAME" );
-        String INSTALL_VAR_PATH = p.getProperty( "INSTALL_VAR_PATH" );
+        String INSTALL_VAR_NAME = getProperty( "INSTALL_VAR_NAME" );
+        String INSTALL_VAR_VARIABLE_NAME = getProperty( "INSTALL_VAR_VARIABLE_NAME" );
+        String INSTALL_VAR_PATH = getProperty( "INSTALL_VAR_PATH" );
         goToAddInstallationVariable();
         addInstallation( INSTALL_VAR_NAME, INSTALL_VAR_VARIABLE_NAME, INSTALL_VAR_PATH, false, false, false );
         assertTextPresent( "Installation name already exists" );
     }
 
-    @Test( dependsOnMethods = { "testAddJdkToolWithoutBuildEnvirotment" } )
+    @Test( dependsOnMethods = { "testAddJdkToolWithoutBuildEnvironment" } )
     public void testEditInstallationTool()
     {
-        String INSTALL_TOOL_JDK_NAME = p.getProperty( "INSTALL_TOOL_JDK_NAME" );
-        String INSTALL_TOOL_JDK_PATH = p.getProperty( "INSTALL_TOOL_JDK_PATH" );
-        String newName = "new_name";
-        goToEditInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, true );
-        editInstallation( newName, "JDK", INSTALL_TOOL_JDK_PATH, true, true );
-        goToEditInstallation( newName, "JDK", INSTALL_TOOL_JDK_PATH, true );
-        editInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, true, true );
+        String INSTALL_TOOL_JDK_NAME = getProperty( "INSTALL_TOOL_JDK_NAME" );
+		String INSTALL_TOOL_JDK_PATH = isWindows() ? getProperty( "INSTALL_TOOL_JDK_PATH" ) :  getEscapeProperty( "INSTALL_TOOL_JDK_PATH" );
+		String newName = "new_name";
+		goToEditInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, true );
+		editInstallation( newName, "JDK", INSTALL_TOOL_JDK_PATH, true, true );
+		goToEditInstallation( newName, "JDK", INSTALL_TOOL_JDK_PATH, true );
+		editInstallation( INSTALL_TOOL_JDK_NAME, "JDK", INSTALL_TOOL_JDK_PATH, true, true );
     }
 
-    @Test( dependsOnMethods = { "testAddInstallationVariableWithBuildEnvirotment" } )
+    @Test( dependsOnMethods = { "testAddInstallationVariableWithBuildEnvironment" } )
     public void testEditInstallationVariable()
     {
-        String INSTALL_VAR_NAME = p.getProperty( "INSTALL_VAR_NAME" );
-        String INSTALL_VAR_VARIABLE_NAME = p.getProperty( "INSTALL_VAR_VARIABLE_NAME" );
-        String INSTALL_VAR_PATH = p.getProperty( "INSTALL_VAR_PATH" );
+        String INSTALL_VAR_NAME = getProperty( "INSTALL_VAR_NAME" );
+        String INSTALL_VAR_VARIABLE_NAME = getProperty( "INSTALL_VAR_VARIABLE_NAME" );
+        String INSTALL_VAR_PATH = getProperty( "INSTALL_VAR_PATH" );
         String newName = "new_name";
         String newVarName = "new_var_name";
         String newPath = "new_path";
@@ -147,14 +149,21 @@ public class InstallationTest
     @Test( dependsOnMethods = { "testEditInstallationTool", "testAddDuplicatedInstallationTool" } )
     public void testDeleteInstallationTool()
     {
-        String INSTALL_TOOL_JDK_NAME = p.getProperty( "INSTALL_TOOL_JDK_NAME" );
+        String INSTALL_TOOL_JDK_NAME = getProperty( "INSTALL_TOOL_JDK_NAME" );
         removeInstallation( INSTALL_TOOL_JDK_NAME );
     }
 
     @Test( dependsOnMethods = { "testEditInstallationVariable", "testAddDuplicatedInstallationVariable" } )
     public void testDeleteInstallationVariable()
     {
-        String INSTALL_VAR_NAME = p.getProperty( "INSTALL_VAR_NAME" );
+        String INSTALL_VAR_NAME = getProperty( "INSTALL_VAR_NAME" );
         removeInstallation( INSTALL_VAR_NAME );
     }
+
+	public static boolean isWindows()
+	{
+		String os = System.getProperty("os.name").toLowerCase();
+		//windows
+	    return (os.indexOf( "win" ) >= 0); 
+	}
 }
@@ -30,36 +30,37 @@ import org.testng.annotations.Test;
         goToAddInstallationVariable();
         addInstallation( INSTALL_VAR_NAME, INSTALL_VAR_VARIABLE_NAME, INSTALL_VAR_PATH, true, false, true );
-        // TODO: Validate build envirotment
+        // TODO: Validate build environment
     }
 

Modified: continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LocalRepositoriesTest.java
URL: http://svn.apache.org/viewvc/continuum/branches/continuum-flat-multi-module/continuum-webapp-test/src/test/testng/org/apache/continuum/web/test/LocalRepositoriesTest.java?rev=941625&r1=941624&r2=941625&view=diff
==============================================================================